format_println

Function format_println 

pub fn format_println<T, F>(
    format_option: FormatOption,
    serializeable_data: T,
    fallback: F,
) -> Result<(), Box<dyn Error>>
where T: Serialize, F: FnOnce(T) -> FormatResult,
Formats serializeable_data using the given format_option, falling back to the fallback function to render human-readable text, and prints to stdout with a newline.