pub enum Reply {
Show 28 variants
Ignore,
Heartbeat,
Version(VersionArgs),
Capabilities(CapabilitiesArgs),
DirCreated(DirCreatedArgs),
DirRenamed(DirRenamedArgs),
DirRemoved(DirRemovedArgs),
DirContentsList(DirContentsListArgs),
FileOpened(FileOpenedArgs),
FileClosed(FileClosedArgs),
UnopenedFileRenamed(UnopenedFileRenamedArgs),
FileRenamed(FileRenamedArgs),
UnopenedFileRemoved(UnopenedFileRemovedArgs),
FileRemoved(FileRemovedArgs),
FileContents(FileContentsArgs),
FileWritten(FileWrittenArgs),
ProcStarted(ProcStartedArgs),
ProcStdinWritten(ProcStdinWrittenArgs),
ProcStdoutContents(ProcStdoutContentsArgs),
ProcStderrContents(ProcStderrContentsArgs),
ProcKilled(ProcKilledArgs),
ProcStatus(ProcStatusArgs),
Error(ReplyError),
Sequence(SequenceArgs),
Batch(BatchArgs),
Forward(ForwardArgs),
Custom(CustomArgs),
InternalDebug(InternalDebugArgs),
}Variants
Ignore
Used when we want to NOT send a reply at all
Heartbeat
Version(VersionArgs)
Capabilities(CapabilitiesArgs)
DirCreated(DirCreatedArgs)
This will be returned upon creating a directory
DirRenamed(DirRenamedArgs)
This will be returned upon renaming a directory
DirRemoved(DirRemovedArgs)
This will be returned upon removing a directory
DirContentsList(DirContentsListArgs)
This will be returned upon collecting the list of files and directories at the provided path
FileOpened(FileOpenedArgs)
This will be returned upon a file being opened or refreshed
FileClosed(FileClosedArgs)
This will be returned upon a file being closed
UnopenedFileRenamed(UnopenedFileRenamedArgs)
This will be returned upon renaming a file
FileRenamed(FileRenamedArgs)
This will be returned upon renaming an open file
UnopenedFileRemoved(UnopenedFileRemovedArgs)
This will be returned upon removing a file
FileRemoved(FileRemovedArgs)
This will be returned upon removing an open file
FileContents(FileContentsArgs)
This will be returned upon reading a file’s contents
FileWritten(FileWrittenArgs)
This will be returned upon writing a file’s contents Contains the updated signature for the file
ProcStarted(ProcStartedArgs)
This will be returned upon starting a process on the server, indicating success and providing an id for sending stdin and receiving stdout/stderr
ProcStdinWritten(ProcStdinWrittenArgs)
This will be returned upon successfully writing to stdin
ProcStdoutContents(ProcStdoutContentsArgs)
This will be returned upon receiving stdout from a remote process on the server, if enabled when first executing
ProcStderrContents(ProcStderrContentsArgs)
This will be returned upon receiving stderr from a remote process on the server, if enabled when first executing
ProcKilled(ProcKilledArgs)
This will be returned upon attempting to kill a process
ProcStatus(ProcStatusArgs)
This will be returned reporting the status of the process, indicating if still running or if has completed (and the exit code)
Error(ReplyError)
This will be returned upon encountering an error during evaluation
Sequence(SequenceArgs)
This will be returned upon successfully evaluating a sequence of operations
Batch(BatchArgs)
This will be returned upon successfully evaluating a batch of operations in parallel
Forward(ForwardArgs)
This will be sent to either the client or server and the msg will be passed along to the associated address (if possible)
Custom(CustomArgs)
This will be sent in either direction to provide a custom content that would be evaluated through user-implemented handlers
InternalDebug(InternalDebugArgs)
For debugging purposes when needing to query the state of client/server