pub enum SerErrorKind {
Show 19 variants
NotFound,
PermissionDenied,
ConnectionRefused,
ConnectionReset,
ConnectionAborted,
NotConnected,
AddrInUse,
AddrNotAvailable,
BrokenPipe,
AlreadyExists,
WouldBlock,
InvalidInput,
InvalidData,
TimedOut,
WriteZero,
Interrupted,
Other,
UnexpectedEof,
NonExhaustive,
}Expand description
This is a hack for us to have both serde serialization and JSON schema implemented for io::ErrorKind; we have custom serializer/deserializer for serde but no way to provide a custom function for schema
Variants
NotFound
PermissionDenied
ConnectionRefused
ConnectionReset
ConnectionAborted
NotConnected
AddrInUse
AddrNotAvailable
BrokenPipe
AlreadyExists
WouldBlock
InvalidInput
InvalidData
TimedOut
WriteZero
Interrupted
Other
UnexpectedEof
NonExhaustive
For types that are added later that are not covered