Module request

Module request 

Structs

BatchArgs
Represents arguments to a request for a batch of operations
CapabilitiesArgs
CloseFileArgs
CreateDirArgs
CustomArgs
ExecProcArgs
ForwardArgs
InternalDebugArgs
KillProcArgs
LazilyTransformedRequest
Represents request that will be transformed at runtime replyd on some prior input
ListDirContentsArgs
OpenFileArgs
ReadFileArgs
ReadProcStatusArgs
ReadProcStderrArgs
ReadProcStdoutArgs
RemoveDirArgs
RemoveFileArgs
RemoveUnopenedFileArgs
RenameDirArgs
RenameFileArgs
RenameUnopenedFileArgs
SequenceArgs
Represents arguments to a request for a sequence of operations
TransformRule
Represents a transformation to apply against some request; uses syntax like JSONPath in that $.field can be used to reference the fields of the objects
WriteFileArgs
WriteProcStdinArgs

Enums

Request
TransformRequestError
Represents an error that can occur when transforming request replyd on prior results from a sequential operation