Request

Enum Request 

pub enum Request {
Show 26 variants Heartbeat, Version, Capabilities, CreateDir(CreateDirArgs), RenameDir(RenameDirArgs), RemoveDir(RemoveDirArgs), ListDirContents(ListDirContentsArgs), OpenFile(OpenFileArgs), CloseFile(CloseFileArgs), RenameUnopenedFile(RenameUnopenedFileArgs), RenameFile(RenameFileArgs), RemoveUnopenedFile(RemoveUnopenedFileArgs), RemoveFile(RemoveFileArgs), ReadFile(ReadFileArgs), WriteFile(WriteFileArgs), ExecProc(ExecProcArgs), WriteProcStdin(WriteProcStdinArgs), ReadProcStdout(ReadProcStdoutArgs), ReadProcStderr(ReadProcStderrArgs), KillProc(KillProcArgs), ReadProcStatus(ReadProcStatusArgs), Sequence(SequenceArgs), Batch(BatchArgs), Forward(ForwardArgs), Custom(CustomArgs), InternalDebug(InternalDebugArgs),
}

Variants



Heartbeat



Version



Capabilities



CreateDir(CreateDirArgs)

This will be sent to indicate the desire to create a new directory



RenameDir(RenameDirArgs)

This will be sent to indicate the desire to rename a directory



RemoveDir(RemoveDirArgs)

This will be sent to indicate the desire to remove a directory



ListDirContents(ListDirContentsArgs)

This will be sent to indicate the desire to list all files/directories at the provided path



OpenFile(OpenFileArgs)

This will be sent to indicate the desire to read/write a file, and can also be used to retrieve an already-open file’s id/sig



CloseFile(CloseFileArgs)

This will be sent to indicate the desire to close an open file



RenameUnopenedFile(RenameUnopenedFileArgs)

This will be sent to indicate the desire to rename a file



RenameFile(RenameFileArgs)

This will be sent to indicate the desire to rename an open file



RemoveUnopenedFile(RemoveUnopenedFileArgs)

This will be sent to indicate the desire to remove a file



RemoveFile(RemoveFileArgs)

This will be sent to indicate the desire to remove an open file



ReadFile(ReadFileArgs)

This will be sent to indicate the desire to read a file’s contents



WriteFile(WriteFileArgs)

This will be sent to indicate the desire to write a file’s contents



ExecProc(ExecProcArgs)

This will be sent to execute a remote proccess on the server



WriteProcStdin(WriteProcStdinArgs)

This will be sent to feed input to a remote process on the server, if enabled when first executing



ReadProcStdout(ReadProcStdoutArgs)

This will be sent to request all stdout for a remote process on the server since the last request was made



ReadProcStderr(ReadProcStderrArgs)

This will be sent to request all stderr for a remote process on the server since the last request was made



KillProc(KillProcArgs)

This will be sent to kill a remote process on the server



ReadProcStatus(ReadProcStatusArgs)

This will be sent to request the status of a running process on the server



Sequence(SequenceArgs)

This will be sent to execute a collection of operations sequentially



Batch(BatchArgs)

This will be sent to execute a collection of operations in parallel



Forward(ForwardArgs)

This will be sent to either the client or server and the msg will be passed along to the associated address (if possible)



Custom(CustomArgs)

This will be sent in either direction to provide a custom content that would be evaluated through user-implemented handlers



InternalDebug(InternalDebugArgs)

For debugging purposes when needing to query the state of client/server

Implementations

Source

impl Request

pub fn into_lazily_transformed( self, rules: Vec<TransformRule>, ) -> LazilyTransformedRequest

Converts a request into a lazily transformed request using the provided rules as transformation specifications