pub struct LazilyTransformedRequest {
pub rules: Vec<TransformRule>,
pub raw_request: Request,
}Expand description
Represents request that will be transformed at runtime replyd on some prior input
Fields
rules: Vec<TransformRule>Represents collection of transformation rules to apply to raw request
raw_request: RequestRepresents request prior to being transformed
Implementations
Sourceimpl LazilyTransformedRequest
impl LazilyTransformedRequest
pub fn new(raw_request: Request, rules: Vec<TransformRule>) -> Self
Sourcepub fn into_raw_request(self) -> Request
pub fn into_raw_request(self) -> Request
Converts to the raw request with no transformations applied
Sourcepub fn transform_with_reply(
&self,
reply: &Reply,
) -> Result<Request, TransformRequestError>
pub fn transform_with_reply( &self, reply: &Reply, ) -> Result<Request, TransformRequestError>
Performs the transformation of request by applying all rules in order and returning the resulting request