Msg

Struct Msg 

pub struct Msg {
    pub header: Header,
    pub parent_header: Option<Header>,
    pub content: Content,
}

Fields

header: Header

Information associated with this message

parent_header: Option<Header>

Information associated with the parent of this message to provide origin context

content: Content

Content within the message

Implementations

Source

impl Msg

pub fn new(content: Content, parent_header: Option<Header>) -> Self

pub fn to_vec(&self) -> Result<Vec<u8>, MsgError>

pub fn from_slice(slice: &[u8]) -> Result<Self, MsgError>

pub fn with_parent_header(&mut self, header: Header) -> &mut Self

Sets the parent header of this msg with that of the provided header

pub fn with_parent(&mut self, parent: &Self) -> &mut Self

Sets the parent header of this msg with that of the provided parent