pub struct Server<A, B>where
A: Authenticator,
B: Bicrypter,{ /* private fields */ }Expand description
Represents a server configuration prior to listening
Implementations
Sourceimpl<A, B> Server<A, B>
impl<A, B> Server<A, B>
Sourcepub async fn listen(self) -> Result<ListeningServer>
pub async fn listen(self) -> Result<ListeningServer>
Starts actively listening for msgs via the specified transport medium
Will fail if using TCP transport as requires Clone; should instead
use cloneable_listen if using TCP
Sourceimpl<A, B> Server<A, B>
impl<A, B> Server<A, B>
Sourcepub async fn cloneable_listen(self) -> Result<ListeningServer>
pub async fn cloneable_listen(self) -> Result<ListeningServer>
Starts actively listening for msgs via the specified transport medium, using cloneable methods for Authenticator and Bicrypter operations