ServerBuilder

Struct ServerBuilder 

pub struct ServerBuilder<A, B>
where A: Authenticator, B: Bicrypter,
{ /* private fields */ }
Builder for Server.

Implementations

Source

impl<A, B> ServerBuilder<A, B>

pub fn packet_ttl(&mut self, value: Duration) -> &mut Self

TTL to collect all packets for a msg

pub fn authenticator(&mut self, value: A) -> &mut Self

Used to sign & verify msgs

pub fn bicrypter(&mut self, value: B) -> &mut Self

Used to encrypt & decrypt msgs

pub fn transport(&mut self, value: Transport) -> &mut Self

Transportation mechanism & address to listen on

pub fn buffer(&mut self, value: usize) -> &mut Self

Internal buffer for cross-thread messaging

pub fn cleanup_interval(&mut self, value: Duration) -> &mut Self

Interval at which cleanup of dangling resources is performed

pub fn file_ttl(&mut self, value: Duration) -> &mut Self

TTL for an untouched, open file before it is closed during cleanup

pub fn proc_ttl(&mut self, value: Duration) -> &mut Self

TTL for an untouched, running process before it is killed during cleanup

pub fn dead_proc_ttl(&mut self, value: Duration) -> &mut Self

TTL for an untouched, dead process before it is removed during cleanup

pub fn build(&self) -> Result<Server<A, B>, String>

Builds a new Server.

Errors

If a required field has not been initialized.