pub struct TransformRule {
pub path: String,
pub value: String,
}Expand description
Represents a transformation to apply against some request; uses syntax like JSONPath in that $.field can be used to reference the fields of the objects
Fields
path: StringRepresents the key (at a JSON level) to transform for some request; this will be interpolated using $ to represent the root of the current object (request)
value: StringRepresents the new value to apply to the key; this will be interpolated replyd on a previous result if present using $ to represent the root of the previous output request as a JSON object and dot notation for the nested keys