Module exec

Module exec 

Enums

Error

Functions

loop_timeout
Invokes a function repeatedly until it yields Some(T); if a timeout is reached, the function will return an error
loop_timeout_panic
Invokes a function repeatedly until it yields true; if a timeout is reached, the function will panic