CallbackManager

Struct CallbackManager 

pub struct CallbackManager<T> { /* private fields */ }
Synchronous manager of one-time callback functions that are allocated on the heap

Implementations

Source

impl<T> CallbackManager<T>

pub fn add_callback( &mut self, id: u32, callback: impl FnOnce(&T) + Send + 'static, )

Adds a new callback, associated with the given id

pub fn take_callback(&mut self, id: u32) -> Option<Box<dyn FnOnce(&T) + Send>>

Retrieves the callback with the associated id, but does not invoke it

pub fn invoke_callback(&mut self, id: u32, input: &T)

Retrieves and invokes the callback with the associated id