Delay

Struct Delay 

pub struct Delay { /* private fields */ }
Represents a delayed execution of a function

Implementations

Source

impl Delay

pub fn spawn<F, T>(timeout: Duration, f: F) -> Self
where F: FnOnce() -> T + Send + 'static,

Spawns a new thread that will invoke the provided function after the given timeout has been exceeded. There is no guarantee that the function will be executed exactly on the given time, only that it will be executed no earlier than until the specified duration has elapsed

pub fn cancel(&self)

Cancels the delayed execution, if it has not yet occurred