DelimiterReader

Struct DelimiterReader 

pub struct DelimiterReader {
    pub delimiter: Vec<u8>,
    /* private fields */
}
Reader that takes closure to perform actual read, supporting sync and async reads, buffering, and extracting data separated by a delimiter

Fields

delimiter: Vec<u8>

The delimiter to look for in read data

Implementations

Source

impl DelimiterReader

pub fn new_with_delimiter(max_data_size: usize, delimiter: &[u8]) -> Self

pub fn new(max_data_size: usize) -> Self

pub fn read<F>(&mut self, data: &mut [u8], f: F) -> Result<usize>
where F: FnOnce(&mut [u8]) -> Result<usize>,

Performs an synchronous read using the given synchronous closure

pub async fn async_read<R, F>(&mut self, data: &mut [u8], r: R) -> Result<usize>
where R: FnOnce(&mut [u8]) -> F, F: Future<Output = Result<usize>>,

Performs an asynchronous read using the given asynchronous closure