pub struct Msg {
pub header: Header,
pub parent_header: Option<Header>,
pub content: Content,
}Fields
header: HeaderInformation associated with this message
parent_header: Option<Header>Information associated with the parent of this message to provide origin context
content: ContentContent within the message
Implementations
Sourceimpl Msg
impl Msg
pub fn new(content: Content, parent_header: Option<Header>) -> Self
pub fn to_vec(&self) -> Result<Vec<u8>, MsgError>
pub fn from_slice(slice: &[u8]) -> Result<Self, MsgError>
Sourcepub fn with_parent_header(&mut self, header: Header) -> &mut Self
pub fn with_parent_header(&mut self, header: Header) -> &mut Self
Sets the parent header of this msg with that of the provided header
Sourcepub fn with_parent(&mut self, parent: &Self) -> &mut Self
pub fn with_parent(&mut self, parent: &Self) -> &mut Self
Sets the parent header of this msg with that of the provided parent