pub struct ServerBuilder<A, B>where
A: Authenticator,
B: Bicrypter,{ /* private fields */ }Expand description
Builder for Server.
Implementations
Sourceimpl<A, B> ServerBuilder<A, B>
impl<A, B> ServerBuilder<A, B>
Sourcepub fn packet_ttl(&mut self, value: Duration) -> &mut Self
pub fn packet_ttl(&mut self, value: Duration) -> &mut Self
TTL to collect all packets for a msg
Sourcepub fn authenticator(&mut self, value: A) -> &mut Self
pub fn authenticator(&mut self, value: A) -> &mut Self
Used to sign & verify msgs
Sourcepub fn transport(&mut self, value: Transport) -> &mut Self
pub fn transport(&mut self, value: Transport) -> &mut Self
Transportation mechanism & address to listen on
Sourcepub fn cleanup_interval(&mut self, value: Duration) -> &mut Self
pub fn cleanup_interval(&mut self, value: Duration) -> &mut Self
Interval at which cleanup of dangling resources is performed
Sourcepub fn file_ttl(&mut self, value: Duration) -> &mut Self
pub fn file_ttl(&mut self, value: Duration) -> &mut Self
TTL for an untouched, open file before it is closed during cleanup
Sourcepub fn proc_ttl(&mut self, value: Duration) -> &mut Self
pub fn proc_ttl(&mut self, value: Duration) -> &mut Self
TTL for an untouched, running process before it is killed during cleanup
Sourcepub fn dead_proc_ttl(&mut self, value: Duration) -> &mut Self
pub fn dead_proc_ttl(&mut self, value: Duration) -> &mut Self
TTL for an untouched, dead process before it is removed during cleanup