Enums
Functions
- loop_
timeout - Invokes a function repeatedly until it yields Some(T); if a timeout is reached, the function will return an error
- loop_
timeout_ panic - Invokes a function repeatedly until it yields true; if a timeout is reached, the function will panic