pub struct CallbackManager<T> { /* private fields */ }Expand description
Synchronous manager of one-time callback functions that are allocated on the heap
Implementations
Sourceimpl<T> CallbackManager<T>
impl<T> CallbackManager<T>
Sourcepub fn add_callback(
&mut self,
id: u32,
callback: impl FnOnce(&T) + Send + 'static,
)
pub fn add_callback( &mut self, id: u32, callback: impl FnOnce(&T) + Send + 'static, )
Adds a new callback, associated with the given id
Sourcepub fn take_callback(&mut self, id: u32) -> Option<Box<dyn FnOnce(&T) + Send>>
pub fn take_callback(&mut self, id: u32) -> Option<Box<dyn FnOnce(&T) + Send>>
Retrieves the callback with the associated id, but does not invoke it
Sourcepub fn invoke_callback(&mut self, id: u32, input: &T)
pub fn invoke_callback(&mut self, id: u32, input: &T)
Retrieves and invokes the callback with the associated id